@@ -11,7 +11,6 @@
     by the membership of KDE e.V.), which shall act as a proxy
     defined in Section 14 of version 3 of the license.
 
-
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -25,20 +24,21 @@
 #ifndef POSTEROUSCONFIG_H
 #define POSTEROUSCONFIG_H
 
-#include <kcmodule.h>
+#include <KCModule>
+
 #include "ui_posterousprefs.h"
 
 class PosterousConfig : public KCModule
 {
     Q_OBJECT
 public:
-    PosterousConfig ( QWidget* parent, const QVariantList& );
+    PosterousConfig(QWidget *parent, const QVariantList &);
     ~PosterousConfig();
 
     virtual void save();
     virtual void load();
 
-protected slots:
+protected Q_SLOTS:
     void emitChanged();
 
 private:
